==> eam-wshub-proxyclient-11.4-11-sources.jar: net/datastream/schemas/mp_entities/workroute_001/WorkRoute.java <==

package net.datastream.schemas.mp_entities.workroute_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.CATEGORYID;
import net.datastream.schemas.mp_fields.CLASSID_Type;
import net.datastream.schemas.mp_fields.REVISIONCONTROL_Type;
import net.datastream.schemas.mp_fields.ROUTE_Type;
import net.datastream.schemas.mp_fields.STATUS_Type;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ROUTEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CATEGORYID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ROUTETEMPLATE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CLASSID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}REVISIONSTATUS"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LINKGISWO" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}REVISIONCONTROL" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="recordid" type="{http://www.w3.org/2001/XMLSchema}long" />
 *       &lt;attribute name="user_entity" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       &lt;attribute name="system_entity" type="{http://www.w3.org/2001/XMLSchema}string" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "routeid",
    "categoryid",
    "routetemplate",
    "classid",
    "revisionstatus",
    "linkgiswo",
    "revisioncontrol"
})
@XmlRootElement(name = "WorkRoute")
public class WorkRoute {

    @XmlElement(name = "ROUTEID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected ROUTE_Type routeid;
    @XmlElement(name = "CATEGORYID", namespace = "http://schemas.datastream.net/MP_fields")
    protected CATEGORYID categoryid;
    @XmlElement(name = "ROUTETEMPLATE", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected String routetemplate;
    @XmlElement(name = "CLASSID", namespace = "http://schemas.datastream.net/MP_fields")
    protected CLASSID_Type classid;
    @XmlElement(name = "REVISIONSTATUS", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected STATUS_Type revisionstatus;
    @XmlElement(name = "LINKGISWO", namespace = "http://schemas.datastream.net/MP_fields")
    protected String linkgiswo;
    @XmlElement(name = "REVISIONCONTROL", namespace = "http://schemas.datastream.net/MP_fields")
    protected REVISIONCONTROL_Type revisioncontrol;
    @XmlAttribute(name = "recordid")
    protected Long recordid;
    @XmlAttribute(name = "user_entity")
    protected String user_Entity;
    @XmlAttribute(name = "system_entity")
    protected String system_Entity;

    /**
     * Obtient la valeur de la propriété routeid.
     * 
     * @return
     *     possible object is
     *     {@link ROUTE_Type }
     *     
     */
    public ROUTE_Type getROUTEID() {
        return routeid;
    }

    /**
     * Définit la valeur de la propriété routeid.
     * 
     * @param value
     *     allowed object is
     *     {@link ROUTE_Type }
     *     
     */
    public void setROUTEID(ROUTE_Type value) {
        this.routeid = value;
    }

    /**
     * Obtient la valeur de la propriété categoryid.
     * 
     * @return
     *     possible object is
     *     {@link CATEGORYID }
     *     
     */
    public CATEGORYID getCATEGORYID() {
        return categoryid;
    }

    /**
     * Définit la valeur de la propriété categoryid.
     * 
     * @param value
     *     allowed object is
     *     {@link CATEGORYID }
     *     
     */
    public void setCATEGORYID(CATEGORYID value) {
        this.categoryid = value;
    }

    /**
     * Obtient la valeur de la propriété routetemplate.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getROUTETEMPLATE() {
        return routetemplate;
    }

    /**
     * Définit la valeur de la propriété routetemplate.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setROUTETEMPLATE(String value) {
        this.routetemplate = value;
    }

    /**
     * Obtient la valeur de la propriété classid.
     * 
     * @return
     *     possible object is
     *     {@link CLASSID_Type }
     *     
     */
    public CLASSID_Type getCLASSID() {
        return classid;
    }

    /**
     * Définit la valeur de la propriété classid.
     * 
     * @param value
     *     allowed object is
     *     {@link CLASSID_Type }
     *     
     */
    public void setCLASSID(CLASSID_Type value) {
        this.classid = value;
    }

    /**
     * Obtient la valeur de la propriété revisionstatus.
     * 
     * @return
     *     possible object is
     *     {@link STATUS_Type }
     *     
     */
    public STATUS_Type getREVISIONSTATUS() {
        return revisionstatus;
    }

    /**
     * Définit la valeur de la propriété revisionstatus.
     * 
     * @param value
     *     allowed object is
     *     {@link STATUS_Type }
     *     
     */
    public void setREVISIONSTATUS(STATUS_Type value) {
        this.revisionstatus = value;
    }

    /**
     * Obtient la valeur de la propriété linkgiswo.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLINKGISWO() {
        return linkgiswo;
    }

    /**
     * Définit la valeur de la propriété linkgiswo.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLINKGISWO(String value) {
        this.linkgiswo = value;
    }

    /**
     * Obtient la valeur de la propriété revisioncontrol.
     * 
     * @return
     *     possible object is
     *     {@link REVISIONCONTROL_Type }
     *     
     */
    public REVISIONCONTROL_Type getREVISIONCONTROL() {
        return revisioncontrol;
    }

    /**
     * Définit la valeur de la propriété revisioncontrol.
     * 
     * @param value
     *     allowed object is
     *     {@link REVISIONCONTROL_Type }
     *     
     */
    public void setREVISIONCONTROL(REVISIONCONTROL_Type value) {
        this.revisioncontrol = value;
    }

    /**
     * Obtient la valeur de la propriété recordid.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getRecordid() {
        return recordid;
    }

    /**
     * Définit la valeur de la propriété recordid.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setRecordid(Long value) {
        this.recordid = value;
    }

    /**
     * Obtient la valeur de la propriété user_Entity.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUser_Entity() {
        return user_Entity;
    }

    /**
     * Définit la valeur de la propriété user_Entity.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUser_Entity(String value) {
        this.user_Entity = value;
    }

    /**
     * Obtient la valeur de la propriété system_Entity.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSystem_Entity() {
        return system_Entity;
    }

    /**
     * Définit la valeur de la propriété system_Entity.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSystem_Entity(String value) {
        this.system_Entity = value;
    }

}

==> eam-wshub-proxyclient-11.7-2-sources.jar: net/datastream/schemas/mp_entities/workroute_001/WorkRoute.java <==

package net.datastream.schemas.mp_entities.workroute_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.CATEGORYID;
import net.datastream.schemas.mp_fields.CLASSID_Type;
import net.datastream.schemas.mp_fields.REVISIONCONTROL_Type;
import net.datastream.schemas.mp_fields.ROUTE_Type;
import net.datastream.schemas.mp_fields.STATUS_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ROUTEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CATEGORYID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ROUTETEMPLATE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CLASSID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}REVISIONSTATUS"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LINKGISWO" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}REVISIONCONTROL" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="recordid" type="{http://www.w3.org/2001/XMLSchema}long" />
 *       &lt;attribute name="user_entity" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       &lt;attribute name="system_entity" type="{http://www.w3.org/2001/XMLSchema}string" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "routeid",
    "categoryid",
    "routetemplate",
    "classid",
    "revisionstatus",
    "linkgiswo",
    "revisioncontrol"
})
@XmlRootElement(name = "WorkRoute")
public class WorkRoute {

    @XmlElement(name = "ROUTEID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected ROUTE_Type routeid;
    @XmlElement(name = "CATEGORYID", namespace = "http://schemas.datastream.net/MP_fields")
    protected CATEGORYID categoryid;
    @XmlElement(name = "ROUTETEMPLATE", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected String routetemplate;
    @XmlElement(name = "CLASSID", namespace = "http://schemas.datastream.net/MP_fields")
    protected CLASSID_Type classid;
    @XmlElement(name = "REVISIONSTATUS", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected STATUS_Type revisionstatus;
    @XmlElement(name = "LINKGISWO", namespace = "http://schemas.datastream.net/MP_fields")
    protected String linkgiswo;
    @XmlElement(name = "REVISIONCONTROL", namespace = "http://schemas.datastream.net/MP_fields")
    protected REVISIONCONTROL_Type revisioncontrol;
    @XmlAttribute(name = "recordid")
    protected Long recordid;
    @XmlAttribute(name = "user_entity")
    protected String user_Entity;
    @XmlAttribute(name = "system_entity")
    protected String system_Entity;

    /**
     * Gets the value of the routeid property.
     * 
     * @return
     *     possible object is
     *     {@link ROUTE_Type }
     *     
     */
    public ROUTE_Type getROUTEID() {
        return routeid;
    }

    /**
     * Sets the value of the routeid property.
     * 
     * @param value
     *     allowed object is
     *     {@link ROUTE_Type }
     *     
     */
    public void setROUTEID(ROUTE_Type value) {
        this.routeid = value;
    }

    /**
     * Gets the value of the categoryid property.
     * 
     * @return
     *     possible object is
     *     {@link CATEGORYID }
     *     
     */
    public CATEGORYID getCATEGORYID() {
        return categoryid;
    }

    /**
     * Sets the value of the categoryid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CATEGORYID }
     *     
     */
    public void setCATEGORYID(CATEGORYID value) {
        this.categoryid = value;
    }

    /**
     * Gets the value of the routetemplate property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getROUTETEMPLATE() {
        return routetemplate;
    }

    /**
     * Sets the value of the routetemplate property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setROUTETEMPLATE(String value) {
        this.routetemplate = value;
    }

    /**
     * Gets the value of the classid property.
     * 
     * @return
     *     possible object is
     *     {@link CLASSID_Type }
     *     
     */
    public CLASSID_Type getCLASSID() {
        return classid;
    }

    /**
     * Sets the value of the classid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CLASSID_Type }
     *     
     */
    public void setCLASSID(CLASSID_Type value) {
        this.classid = value;
    }

    /**
     * Gets the value of the revisionstatus property.
     * 
     * @return
     *     possible object is
     *     {@link STATUS_Type }
     *     
     */
    public STATUS_Type getREVISIONSTATUS() {
        return revisionstatus;
    }

    /**
     * Sets the value of the revisionstatus property.
     * 
     * @param value
     *     allowed object is
     *     {@link STATUS_Type }
     *     
     */
    public void setREVISIONSTATUS(STATUS_Type value) {
        this.revisionstatus = value;
    }

    /**
     * Gets the value of the linkgiswo property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLINKGISWO() {
        return linkgiswo;
    }

    /**
     * Sets the value of the linkgiswo property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLINKGISWO(String value) {
        this.linkgiswo = value;
    }

    /**
     * Gets the value of the revisioncontrol property.
     * 
     * @return
     *     possible object is
     *     {@link REVISIONCONTROL_Type }
     *     
     */
    public REVISIONCONTROL_Type getREVISIONCONTROL() {
        return revisioncontrol;
    }

    /**
     * Sets the value of the revisioncontrol property.
     * 
     * @param value
     *     allowed object is
     *     {@link REVISIONCONTROL_Type }
     *     
     */
    public void setREVISIONCONTROL(REVISIONCONTROL_Type value) {
        this.revisioncontrol = value;
    }

    /**
     * Gets the value of the recordid property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getRecordid() {
        return recordid;
    }

    /**
     * Sets the value of the recordid property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setRecordid(Long value) {
        this.recordid = value;
    }

    /**
     * Gets the value of the user_Entity property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUser_Entity() {
        return user_Entity;
    }

    /**
     * Sets the value of the user_Entity property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUser_Entity(String value) {
        this.user_Entity = value;
    }

    /**
     * Gets the value of the system_Entity property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSystem_Entity() {
        return system_Entity;
    }

    /**
     * Sets the value of the system_Entity property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSystem_Entity(String value) {
        this.system_Entity = value;
    }

}
